nltk package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   nltk.app
   nltk.ccg
   nltk.chat
   nltk.chunk
   nltk.classify
   nltk.cluster
   nltk.corpus
   nltk.draw
   nltk.inference
   nltk.lm
   nltk.metrics
   nltk.misc
   nltk.parse
   nltk.sem
   nltk.sentiment
   nltk.stem
   nltk.tag
   nltk.tbl
   nltk.tokenize
   nltk.translate
   nltk.tree
   nltk.twitter

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.book
   nltk.cli
   nltk.collections
   nltk.collocations
   nltk.compat
   nltk.data
   nltk.decorators
   nltk.downloader
   nltk.featstruct
   nltk.grammar
   nltk.help
   nltk.internals
   nltk.jsontags
   nltk.langnames
   nltk.lazyimport
   nltk.probability
   nltk.tabdata
   nltk.text
   nltk.tgrep
   nltk.toolbox
   nltk.treeprettyprinter
   nltk.treetransforms
   nltk.util
   nltk.wsd

Module contents
---------------

.. automodule:: nltk
   :members:
   :undoc-members:
   :show-inheritance:
